/*
 * Copyright (c) 2018 Samsung Electronics Co., Ltd All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include <tzplatform_config.h>

#include "libmedia_thumbnail_unittest.h"
#include "media-util.h"
#include "media-thumbnail.h"

#define GTEST_IMAGE_FILE_PATH		tzplatform_mkpath(TZ_SYS_BIN, "libmedia-thumbnail-unittest.jpg")

#define THUMBNAIL_WIDTH			512
#define THUMBNAIL_HEIGHT		288

using ::testing::InitGoogleTest;
using ::testing::Test;
using ::testing::TestCase;

class libmedia_thumbnail_Test : public ::testing::Test {
	protected:
		void SetUp() {
			std::cout << "SetUp()" << std::endl;
		}

		void TearDown() {
			std::cout << "TearDown()" << std::endl;
		}
};

TEST(libmedia_thumbnail_Test, thumbnail_request_from_db_async_n)
{
	int ret = MS_MEDIA_ERR_NONE;

	ret = thumbnail_request_from_db_async(0, NULL, NULL, NULL, 5001);
	EXPECT_EQ(ret, MS_MEDIA_ERR_INVALID_PARAMETER);

	ret = thumbnail_request_from_db_async(0, GTEST_IMAGE_FILE_PATH, NULL, NULL, 5001);
	EXPECT_EQ(ret, MS_MEDIA_ERR_INVALID_PARAMETER);
}

TEST(libmedia_thumbnail_Test, thumbnail_request_cancel_media_n)
{
	int ret = MS_MEDIA_ERR_NONE;

	ret = thumbnail_request_cancel_media(0);
	EXPECT_EQ(ret, MS_MEDIA_ERR_INTERNAL);
}

int main(int argc, char **argv)
{
	InitGoogleTest(&argc, argv);

	return RUN_ALL_TESTS();
}
